@@ -50,8 +50,13 @@ class EasyWorksheet():
     def table(self):
         return self._table
 
+    @property
+    def worksheet(self):
+        return self._worksheet
+
+
     def set_table(self, table):
-        self.table = table
+        self._table = table
         
     def push(self, cell_indexes=[]):
         cell_indexes = set(cell_indexes)
@@ -123,6 +128,7 @@ class EasyWorksheet():
         return pd.DataFrame(rows)
 
 
+
 class EasySpreadsheet():
 
     def __init__(self, auth_json, spreadsheet_id):
@@ -149,8 +155,8 @@ class EasySpreadsheet():
 
         return gc.open_by_url(spreadsheet_url)
 
-    def get_easy_worksheet(self, worksheet_name):
-        return EasyWorksheet(self._sheet.worksheet(worksheet_name))
+    def get_easy_worksheet(self, worksheet_name, **argv):
+        return EasyWorksheet(self._sheet.worksheet(worksheet_name, **argv))
 
     def get_worksheet(self, worksheet_name):
         return self._sheet.worksheet(worksheet_name)
@@ -164,7 +170,22 @@ class EasySpreadsheet():
                 return self._sheet.del_worksheet(worksheet)
 
         return None
-            
+
+    def refresh(self):
+        for worksheet in self.sheet.worksheets():
+            handler = self.get_easy_worksheet(worksheet.title)
+            handler.push()
+        
+    def reorder(self, sheet_order):
+        worksheets_in_desired_order = []
+        for sheet_name in sheet_order:
+            for worksheet in self.sheet.worksheets():
+                if sheet_name == worksheet.title:
+                    worksheets_in_desired_order.append(worksheet)
+                    break
+
+        self.sheet.reorder_worksheets(worksheets_in_desired_order)
+
     @staticmethod
     def allcombinations(alphabet, minlen=1, maxlen=None):
         thislen = minlen
